<?php



namespace App\Http\Controllers;



use App\Apm;

use App\Linea;

use App\Gira;

use App\DistribucionFichero;

use App\DistribucionFicheroInfo;

use App\User;

use App\ApmStatus;

use App\Socio;

use Illuminate\Support\Facades\Auth;
use App\Actividad;
use Illuminate\Http\Request;



use Illuminate\Support\Facades\Validator;



class ApmController extends Controller

{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response

     */
    public function index()
    {
        //
        $apms=Apm::with('linea')
                ->with('gira')
                ->get();
        return view('apm.lista',compact('apms'));
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response

     */
    public function create()
    {
        //
        $lineas=Linea::all();
        $giras=Gira::all();
        return view('apm.nuevo',compact('lineas','giras'));
    }
    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request

     * @return \Illuminate\Http\Response

     */
    public function store(Request $request)
    {
        //
        $validator = Validator::make($request->all(), [
            'email' => 'required|unique:users',
        ]);
        if ($validator->fails()) {
            $arrResponse = [
                'message' => 'El correo ya existe'
            ];
            return redirect()->back()->withInput()->with($arrResponse);
        }
        //Nuevo usuario

        $usuario=new User();
        $usuario->name = $request->primer_nombre.' '.$request->segundo_nombre.' '.$request->primer_apellido.' '.$request->segundo_apellido;
        $usuario->email=$request->email;
        $usuario->password=bcrypt($request->password);
        $usuario->id_role=$request->tipo_usuario;
        $usuario->save();
        $apm = new Apm();
        $apm->primer_nombre = $request->primer_nombre;
        $apm->segundo_nombre = $request->segundo_nombre;
        $apm->primer_apellido = $request->primer_apellido;
        $apm->segundo_apellido = $request->segundo_apellido;
        $apm->telefono_apm = $request->celular;
        $apm->direccion_apm = $request->direccion;
        $apm->id_gira = 0;
        $apm->id_linea = $request->linea;
        $apm->id_user =  $usuario->id;
        $apm->save();
        $arrResponse = [
            'message' => 'APM guardado correctamente'
        ];
        return redirect()->route('apm.index')->with($arrResponse);
        dd();
    }
    /**
     * Display the specified resource.
     *
     * @param  \App\Apm  $apm

     * @return \Illuminate\Http\Response

     */
    public function show(Apm $apm)
    {
        //
    }
    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Apm  $apm

     * @return \Illuminate\Http\Response

     */
    public function edit(Apm $apm)
    {
        //
        $lineas=Linea::all();
        $giras=Gira::all();
        $usuario=User::where('id',$apm->id_user)->first();
        //dd($apm);
        return view('apm.editar',compact('lineas','giras','apm','usuario'));
    }
    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request

     * @param  \App\Apm  $apm

     * @return \Illuminate\Http\Response

     */
    public function update(Request $request, Apm $apm)
    {
        //Nuevo usuario

        //dd($request);
        $usuario=User::where('id',$apm->id_user)->first();
        $usuario->name = $request->primer_nombre.' '.$request->segundo_nombre.' '.$request->primer_apellido.' '.$request->segundo_apellido;
        $usuario->email=$request->email;
        if($request->password){
            $usuario->password=bcrypt($request->password);
        }
        $usuario->id_role=$request->tipo_usuario;
        $usuario->update();
        $apm->primer_nombre = $request->primer_nombre;
        $apm->segundo_nombre = $request->segundo_nombre;
        $apm->primer_apellido = $request->primer_apellido;
        $apm->segundo_apellido = $request->segundo_apellido;
        $apm->telefono_apm = $request->celular;
        $apm->direccion_apm = $request->direccion;
        $apm->id_gira = 0;
        $apm->id_linea = $request->linea;
        $apm->update();
        $arrResponse = [
            'message' => 'APM actualizado correctamente'
        ];
        return redirect()->route('apm.index')->with($arrResponse);
        dd();
    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Apm  $apm

     * @return \Illuminate\Http\Response

     */
    public function destroy(Apm $apm)
    {
        //
        User::destroy($apm->id_user);
        Apm::destroy($apm->id);
        $arrResponse = [
            'message' => 'Apm eliminado correctamente'
        ];
        return redirect()->route('apm.index')->with($arrResponse);
    }
    public function calendario(Apm $apm)
    {
        //
        $id_apm=auth()->user()->id;
        $distribucionFichero=DistribucionFichero::where('id_apm_user',$id_apm)
                                                ->where('fecha_asignada_apm','!=',null)
                                                ->with('socio')
                                                ->with('visita')
                                                ->get();
        $visitas=Actividad::where('id_apm',$id_apm)
                                                ->get();
        //dd($distribucionFichero);
        //Status Apm

        $apm_status=ApmStatus::where('id_apm',$id_apm)->where('id_status','<=',1)->orderBy('id', 'DESC')->first()??0;
        if(@$apm_status->id_status==1){
            //Verificar dia

            $fechaAhora=date("Y/m/d");
            $fechaUltimaConexion=date("Y/m/d", strtotime($apm_status->created_at));
            if($fechaAhora!=$fechaUltimaConexion){
                $apm_status->id_status=2;
                $apm_status->update();
                $apm_status=0;
            }else{
                $apm_status=$apm_status->id_status;
            }
        }
        if(count($distribucionFichero)>0){
            foreach($distribucionFichero as $fichero){
                $fondo_item=$fichero->visita==null?'':'#4CAF50';
                $itemsCalendario[]=[
                    'id'=>$fichero['id'],
                    'start'=>$fichero['fecha_asignada_apm'],
                    'title'=>$fichero->socio['primer_nombre_socio'].' '.$fichero->socio['segundo_nombre_socio'].' '.$fichero->socio['primer_apellido_socio'].' '.$fichero->socio['segundo_apellido_socio'],
                    'url'=>route('socio.ficha', ['idSocio' => $fichero['id_socio'],'idDistribucion' => $fichero['id']]),
                    'backgroundColor'=>$fondo_item
                ];
            }
            $ficheros=json_encode($itemsCalendario);
        }else{
            $ficheros='';
        }
        if(count($visitas)>0){
            foreach($visitas as $fichero){
                $fondo_item=$fichero->visita==null?'#FF9800':'#4CAF50';
                $itemsCalendario[]=[
                    'id'=>$fichero->id,
                    'start'=>$fichero->fecha_actividad,
                    'title'=>$fichero->nombre,
                    'url'=>'',
                    'backgroundColor'=>$fondo_item
                ];
            }
            $ficheros=json_encode($itemsCalendario);
        }
        return view('calendario.nuevo',compact('ficheros','apm_status','id_apm'));
    }
    public function planificador(Apm $apm)
    {
        //
        $usuarioId=auth()->user()->id;
        $apm_info=Apm::where('id_user',$usuarioId)->first();
        $medicos=Socio::where('id_gira',$apm_info->id_gira)->where('id_tipo_socio',3)->with('planificador')->get();
        $farmacias=Socio::where('id_gira',$apm_info->id_gira)->where('id_tipo_socio',1)->with('planificador')->get();
        return view('calendario.planificador',compact('medicos','usuarioId','farmacias'));
    }
    public function planificadorGuardarSocio(Request $request){
        //Guardar Socio en Planificador AJAX
        $dayofweek = date('W', strtotime($request->fecha));
        $buscarMedico = DistribucionFichero::where('id_socio',$request->idSocio)->where('estatus',0)->whereRaw("WEEKOFYEAR(fecha_asignada_apm)=$dayofweek")
                                            ->first();
        if($buscarMedico==null){
            $usuarioId=auth()->user()->id;
            $distribucionFichero = new DistribucionFichero();
            $distribucionFichero->id_fichero=1;
            $distribucionFichero->id_socio=$request->idSocio;
            
            $distribucionFichero->id_apm_user=$usuarioId;
            $distribucionFichero->fecha_asignada_apm=$request->fecha;
            $distribucionFichero->estatus=0;
            $distribucionFichero->save();
            $arrResponse = [
                'message' => 'Se actualizo la fecha de la visita.'
            ];
        }else{
            $arrResponse = [
                'message' => 'El médico ya esta agendado.'
            ];
        }

        return response($arrResponse);
    }
    public function planificadorActualizarSocio(Request $request){
        //Actualizar fecha

        $distribucionFichero = DistribucionFichero::where('id',$request->idSocio)->where('estatus',0)
                                ->update(['fecha_asignada_apm' => $request->fecha]);
        $arrResponse = [
            'message' => 'Se actualizo la fecha de la visita.'
        ];
        return response($arrResponse);
    }
    public function status(Request $request){
        $apm=new ApmStatus();
        $apm->id_apm=$request->id_apm;
        $apm->id_status=1;
        $apm->latitud=$request->latitud;
        $apm->longitud=$request->longitud;
        $apm->save();
        $arrResponse = [
            'message' => 'Ya estas activo',
            'id_status'=>$apm

        ];
        return response($arrResponse);
    }
}
