<?php

namespace App\Http\Controllers;
use App\Municipio;
use App\Departamento;
use App\Pais;
use App\Zona;
use App\Region;
use App\Gira;
use App\CodigoPostal;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;

class CodigoPostalController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //

        $codigoPostal=CodigoPostal::with('pais')
                ->with('departamento')
                ->with('municipio')
                ->with('region')
                ->with('gira')
                ->with('zona')
                ->get();
        return view('codigo_postal.lista',compact('codigoPostal'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        $paises=Pais::all();
        $departamentos=Departamento::all();
        $municipios=Municipio::all();
        $zonas=Zona::all();
        $regiones=Region::all();
        $giras=Gira::all();
        return view('codigo_postal.nuevo',compact('paises','departamentos','municipios','zonas','regiones','giras'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $where = [
            'descripcion_zona_codigo_postal' => $request->descripcion,
            'id_pais' => $request->id_pais,
            'id_departamento' => $request->id_departamento,
            'id_municipio' => $request->id_municipio,
            'id_zona' => $request->id_zona,
            'id_gira' => $request->id_gira
        ];
        $verificarRepetido=CodigoPostal::where($where)->first();
        if($verificarRepetido){
            $arrResponse = [
                'message' => 'El Código postal ya existe'
            ];
            return redirect()->route('codigo.index')->with($arrResponse);
            dd();
        }
        $codigo = new CodigoPostal();
        $codigo->descripcion_zona_codigo_postal = $request->descripcion;
        $codigo->id_pais = $request->id_pais;
        $codigo->id_departamento = $request->id_departamento;
        $codigo->id_municipio = $request->id_municipio;
        $codigo->id_zona = $request->id_zona;
        $codigo->id_region = $request->id_region;
        $codigo->id_gira = $request->id_gira;
        $codigo->id_user = Auth::id();
        $codigo->save();
        $arrResponse = [
            'message' => 'Código postal guardada correctamente'
        ];
        return redirect()->route('codigo.index')->with($arrResponse);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(CodigoPostal $codigo)
    {
        //
        $paises=Pais::all();
        $departamentos=Departamento::all();
        $municipios=Municipio::all();
        $zonas=Zona::all();
        $regiones=Region::all();
        $giras=Gira::all();
        return view('codigo_postal.editar',compact('paises','departamentos','municipios','zonas','regiones','giras','codigo'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, CodigoPostal $codigo)
    {
        //
        $codigo->descripcion_zona_codigo_postal = $request->descripcion;
        $codigo->id_pais = $request->id_pais;
        $codigo->id_departamento = $request->id_departamento;
        $codigo->id_municipio = $request->id_municipio;
        $codigo->id_zona = $request->id_zona;
        $codigo->id_region = $request->id_region;
        $codigo->id_gira = $request->id_gira;
        $codigo->id_user = Auth::id();
        $codigo->update();
        $arrResponse = [
            'message' => 'Código postal actualizado correctamente'
        ];
        return redirect()->route('codigo.index')->with($arrResponse);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
        CodigoPostal::destroy($id);
        $arrResponse = [
            'message' => 'Código postal eliminado correctamente'
        ];
        return redirect()->route('codigo.index')->with($arrResponse);
    }
}
