<?php

namespace App\Http\Controllers;

use App\Apm;
use App\Linea;
use App\Gira;
use App\DistribucionFichero;
use App\DistribucionFicheroInfo;
use App\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;

use Illuminate\Support\Facades\Validator;

class ApmController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

        //
        $apms=Apm::with('linea')
                ->with('gira')
                ->get();
        return view('apm.lista',compact('apms'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        $lineas=Linea::all();
        $giras=Gira::all();
        return view('apm.nuevo',compact('lineas','giras'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //

        $validator = Validator::make($request->all(), [
            'email' => 'required|unique:users',
        ]);
        if ($validator->fails()) {
            $arrResponse = [
                'message' => 'El correo ya existe'
            ];
            return redirect()->back()->withInput()->with($arrResponse);
        }
        //Nuevo usuario
        $usuario=new User();
        $usuario->name = $request->primer_nombre.' '.$request->segundo_nombre.' '.$request->primer_apellido.' '.$request->segundo_apellido;
        $usuario->email=$request->email;
        $usuario->password=bcrypt($request->password);
        $usuario->id_role=2;
        $usuario->save();

        $apm = new Apm();
        $apm->primer_nombre = $request->primer_nombre;
        $apm->segundo_nombre = $request->segundo_nombre;
        $apm->primer_apellido = $request->primer_apellido;
        $apm->segundo_apellido = $request->segundo_apellido;
        $apm->telefono_apm = $request->celular;
        $apm->direccion_apm = $request->direccion;
        $apm->id_gira = $request->gira;
        $apm->id_linea = $request->linea;
        $apm->id_user =  $usuario->id;

        $apm->save();
        $arrResponse = [
            'message' => 'APM guardado correctamente'
        ];
        return redirect()->route('apm.index')->with($arrResponse);
        dd();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Apm  $apm
     * @return \Illuminate\Http\Response
     */
    public function show(Apm $apm)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Apm  $apm
     * @return \Illuminate\Http\Response
     */
    public function edit(Apm $apm)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Apm  $apm
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Apm $apm)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Apm  $apm
     * @return \Illuminate\Http\Response
     */
    public function destroy(Apm $apm)
    {
        //
    }
    public function calendario(Apm $apm)
    {
        //
        $distribucionFichero=DistribucionFichero::where('id_apm_user',auth()->user()->id)
                                                ->where('fecha_asignada_apm','!=',null)
                                                ->with('socio')
                                                ->get();

        if(count($distribucionFichero)>0){
            foreach($distribucionFichero as $fichero){
                $itemsCalendario[]=[
                    'id'=>$fichero['id'],
                    'start'=>$fichero['fecha_asignada_apm'],
                    'title'=>$fichero->socio['primer_nombre_socio'].' '.$fichero->socio['segundo_nombre_socio'].' '.$fichero->socio['primer_apellido_socio'].' '.$fichero->socio['segundo_apellido_socio'],
                    'url'=>route('socio.ficha', ['idSocio' => $fichero['id']])
                ];
            }
            $ficheros=json_encode($itemsCalendario);

        }else{
            $ficheros='';
        }

        return view('calendario.nuevo',compact('ficheros'));
    }
    public function planificador(Apm $apm)
    {
        //
        $fechaAhora=date("Y/m/d");
        $distribucionFichero=DistribucionFicheroInfo::where('fecha_final','>=',$fechaAhora)
                                    ->with('ficheros')
                                    ->get();
        if(!isset($distribucionFichero)){
            $distribucionFichero='';
        }

        return view('calendario.planificador',compact('distribucionFichero'));
    }
    public function planificadorGuardarSocio(Request $request){
        //Guardar Socio en Planificador AJAX

        $distribucionFichero = DistribucionFichero::where('id', $request->idSocio)
                                                    ->update(['fecha_asignada_apm' => $request->fecha]);

        $arrResponse = [
            'message' => 'Se actualizo la fecha de la visita.'
        ];
        return response($arrResponse);
    }
}
