<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('layouts/index');
})->middleware('auth');
Route::get('/prueba', 'ApmController@prueba')->name('admin.prueba');

Route::group(['prefix' => 'gerente_mercadeo'], function() {
        Route::get('listado_parrillas', 'ParrillasController@index')->name('marketing.parrillas');
        Route::get('nueva_parrilla', 'ParrillasController@create')->name('marketing.create_parrilla');
        Route::post('guardar_parrilla', 'ParrillasController@store')->name('marketing.guardar_parrilla');
        Route::get('ver_parrilla/{id}', 'ParrillasController@show')->name('marketing.ver_parrilla');
        Route::get('duplicar_parrilla/{id}', 'ParrillasController@duplicar')->name('marketing.duplicar_parrilla');

        Route::get('guardar_planificacion_supervision', 'GerenteProductoController@index')->name('marketing.planificacion_supervision')->middleware('auth');
        Route::get('nueva_producto_gerenete', 'GerenteProductoController@create')->name('marketing.create_gerente_producto')->middleware('auth');
        Route::post('guardar_planificacion_supervision', 'GerenteProductoController@store')->name('marketing.guardar_planificacion_supervision')->middleware('auth');
        //Reportes
        Route::get('reporte_planificacion', 'GerenteMercadeoController@reporte_planificacion')->name('reporte.planificacion');
        Route::get('reporte_visitas', 'GerenteMercadeoController@reporte_visitas')->name('reporte.reporte_visitas');
});
Route::group(['prefix' => 'dashboard'], function() {
    Route::get('gerente_linea', 'GerenteLineaController@index')->name('dashboard.gerente_linea');
    Route::get('gerente_mercadeo', 'GerenteMercadeoController@index')->name('dashboard.gerente_mercadeo');

});
Route::get('lista', 'SociosController@index')->name('socios.index');
Route::group(['prefix' => 'gerente_linea'], function() {

    Route::group(['prefix' => 'territorio'], function() {
        Route::get('lista', 'AsignacionTerritorioController@index')->name('territorio.index');
        Route::get('nueva', 'AsignacionTerritorioController@create')->name('territorio.crear');
        Route::post('guardar', 'AsignacionTerritorioController@store')->name('territorio.guardar');

        Route::get('editar/{id}', 'AsignacionTerritorioController@edit')->name('territorio.editar');
        Route::post('actualizar/{territorio}', 'AsignacionTerritorioController@update')->name('territorio.actualizar');
        Route::get('eliminar/{id}', 'AsignacionTerritorioController@destroy')->name('territorio.eliminar');
    });
    Route::group(['prefix' => 'fichero'], function() {
        Route::get('lista', 'DistribucionFicheroController@index')->name('fichero.index');
        Route::post('nueva', 'DistribucionFicheroController@create')->name('fichero.crear');
        Route::post('guardar', 'DistribucionFicheroController@store')->name('fichero.guardar');
        Route::get('buscar', 'DistribucionFicheroController@buscar')->name('fichero.buscar');

        Route::get('editar/{fichero}', 'DistribucionFicheroController@edit')->name('fichero.editar');
        Route::post('actualizar/{ficheroInfo}', 'DistribucionFicheroController@update')->name('fichero.actualizar');
        Route::get('eliminar/{id}', 'DistribucionFicheroController@destroy')->name('fichero.eliminar');
    });
});
Route::group(['prefix' => 'apm'], function() {
    Route::get('calendario', 'ApmController@calendario')->name('apm.calendario')->middleware('auth');
    Route::post('status', 'ApmController@status')->name('apm.status');
    Route::get('planificador', 'ApmController@planificador')->name('apm.planificador')->middleware('auth');
    Route::post('guardar-socio-planificador', 'ApmController@planificadorGuardarSocio')->name('apm.planificador_guardar')->middleware('auth');
    Route::post('actualizar-socio-planificador', 'ApmController@planificadorActualizarSocio')->name('apm.planificador_actualizar')->middleware('auth');
    Route::get('listado_socios', 'SociosController@listadoSocios')->name('apm.listado_socios');
    Route::get('actividades', 'SociosController@actividades')->name('apm.actividades');
    Route::post('guardar_actividades', 'SociosController@guardarActividades')->name('apm.guardar_actividades');
    
    Route::group(['prefix' => 'socio'], function() {
        Route::get('ficha/{idSocio}/{idDistribucion}', 'FichaSocioController@index')->name('socio.ficha');
        Route::get('ficha_pedido/{idSocio}', 'FichaSocioController@index_pedido')->name('socio.ficha_pedido');
        Route::post('ficha/nueva_cita', 'FichaSocioController@nuevaCita')->name('socio.nueva_cita');
        Route::post('ficha/terminar_visita', 'FichaSocioController@terminarVisita')->name('socio.terminar_visita');
        Route::post('ficha/actualizar_parrilla', 'FichaSocioController@actualizarParrilla')->name('socio.actualizar_parrilla');
        Route::post('ficha/guardar_pedido', 'FichaSocioController@guardarPedido')->name('socio.guardar_pedido');
        Route::post('ficha/mostrar_pedido', 'FichaSocioController@mostrarPedido')->name('socio.mostrar_pedido');
        Route::post('ficha/guardar_pedido_combo', 'FichaSocioController@guardarPedidoCombo')->name('socio.guardar_pedido_combo');
        Route::post('ficha/guardar_comentario', 'FichaSocioController@guardarComentario')->name('socio.guardar_comentario');
        Route::post('ficha/guardar_eva', 'FichaSocioController@guardarEVA')->name('socio.guardar_eva');
        Route::post('ficha/mostrar_pedidoEVA', 'FichaSocioController@mostrarPedidoEVA')->name('socio.mostrar_pedidoEVA');

        Route::post('ficha/consulta_factura', 'FichaSocioController@consultarFactura')->name('socio.consulta_factura');
        Route::post('ficha/consulta_producto', 'FichaSocioController@facturasCliente')->name('socio.consulta_producto');
        Route::post('ficha/productos_facturas', 'FichaSocioController@productosFacturas')->name('socio.productos_facturas');

        Route::get('nuevo', 'SociosController@createSocioApm')->name('socios.crear_por_apm');
        Route::post('guardar_socio', 'SociosController@storeSocioApm')->name('socios.guardar_por_apm');
        Route::post('municipio_socio', 'SociosController@SearchMunicipioSocio')->name('municipio_socio');
    });

});

Route::group(['prefix' => 'admin'], function() {
    Route::group(['prefix' => 'socio'], function() {

        Route::get('nuevo', 'SociosController@create')->name('socios.crear');
        Route::post('guardar', 'SociosController@store')->name('socios.guardar');
        Route::get('codigo_area', 'SociosController@codigosArea')->name('socios.codigos_area');
        Route::get('editar/{id}', 'SociosController@edit')->name('socios.editar');
        Route::get('aprobacion/{id}', 'SociosController@editAprobacion')->name('socios.verificar_socio');
        Route::post('guardar_aprobacion_socio/{idBorrador}', 'SociosController@nuevaAprobacion')->name('socios.guardar_aprobacion');
        Route::get('eliminar_aprobacion/{socio}', 'SociosController@destroyAprobacion')->name('socios.eliminar_aprobacion');
        Route::post('actualizar/{socio}', 'SociosController@update')->name('socios.actualizar');
        Route::get('eliminar/{socio}', 'SociosController@destroy')->name('socios.eliminar');
    });
    Route::get('aprobaciones', 'SociosController@sociosInactivos')->name('socio.aprobaciones');
    //Material Promocional
    Route::get('material_promocional', 'ProductosPromocionalesController@index')->name('marketing.productos_promocionales');
    Route::get('nuevo_material_promocional', 'ProductosPromocionalesController@create')->name('marketing.crear');
    Route::post('nuevo_material_promocional/guardar', 'ProductosPromocionalesController@store')->name('marketing.guardar_promocional');
    Route::get('eliminar_material_promocional/{id}', 'ProductosPromocionalesController@destroy')->name('productos.eliminar_material_promocional');
    Route::get('editar_material_promocional/{object}', 'ProductosPromocionalesController@edit')->name('productos.editar_material_promocional');
    Route::put('actualizar_material_promocional/{object}', 'ProductosPromocionalesController@update')->name('productos.actualizar_material_promocional');

    Route::get('precios', 'PreciosController@index')->name('marketing.precios');
    Route::get('nuevo_listado_precio', 'PreciosController@create')->name('marketing.create_precio');
    Route::get('editar_listado_precio/{lista_precios}', 'PreciosController@edit')->name('marketing.editar_precio');
    Route::post('actualizar_listado_precio/{object}', 'PreciosController@update')->name('marketing.actualizar_precio');
    Route::get('eliminar_listado_precio/{lista_precios}', 'PreciosController@destroy')->name('marketing.eliminar_precio');
    Route::post('guardar_lista', 'PreciosController@store')->name('marketing.guardar_lista');

    Route::get('listado_combos', 'CombosController@index')->name('marketing.combos')->middleware('auth');
    Route::get('nuevo_combo', 'CombosController@create')->name('marketing.create_combo')->middleware('auth');
    Route::post('guardar_combo', 'CombosController@store')->name('marketing.guardar_combo')->middleware('auth');
    Route::get('eliminar_combo/{id}', 'CombosController@destroy')->name('marketing.eliminar_combo');
    Route::get('editar_combo/{id}', 'CombosController@edit')->name('marketing.editar_combo');
    Route::post('actualizar_combo/{combo}', 'CombosController@update')->name('marketing.actualizar_combo');

    Route::group(['prefix' => 'productos'], function() {
        Route::get('listado', 'ProductosController@index')->name('productos.listado');
        Route::get('nuevo', 'ProductosController@create')->name('productos.nuevo');
        Route::post('guardar', 'ProductosController@store')->name('productos.guardar');
        Route::get('listado_precios', 'ProductosController@listadoPrecios')->name('productos.listado_ajax');
        Route::get('eliminar/{id}', 'ProductosController@destroy')->name('productos.eliminar');
        Route::get('editar/{producto}', 'ProductosController@edit')->name('productos.editar');
        Route::post('actualizar/{producto}', 'ProductosController@update')->name('productos.actualizar');
        //Bonificacion
        Route::get('bonificaciones', 'BonificacionController@index')->name('bonificacion.index');
        Route::get('nueva_bonificacion', 'BonificacionController@create')->name('bonificacion.nuevo');
        Route::post('guardar_bonificacion', 'BonificacionController@store')->name('bonificacion.guardar');
        Route::get('eliminar_bonificacion/{id}', 'BonificacionController@destroy')->name('bonificacion.eliminar');
        Route::get('editar_bonificacion/{object}', 'BonificacionController@edit')->name('bonificacion.editar');
        Route::put('actualizar_bonificacion/{object}', 'BonificacionController@update')->name('bonificacion.actualizar');
        //Especialidad
        Route::get('especialidad', 'EspecialidadController@index')->name('especialidad.index');
        Route::get('nueva_especialidad', 'EspecialidadController@create')->name('especialidad.nuevo');
        Route::post('guardar_especialidad', 'EspecialidadController@store')->name('especialidad.guardar');
        Route::get('eliminar_especialidad/{id}', 'EspecialidadController@destroy')->name('especialidad.eliminar');
        Route::get('editar_especialidad/{object}', 'EspecialidadController@edit')->name('especialidad.editar');
        Route::put('actualizar_especialidad/{object}', 'EspecialidadController@update')->name('especialidad.actualizar');
        //Laboratorio
        Route::get('listado_laboratorios', 'ProductoLaboratorioController@index')->name('productos.laboratorios');
        Route::get('nuevo_laboratorio', 'ProductoLaboratorioController@create')->name('productos.nuevo_laboratorio');
        Route::post('guardar_laboratorio', 'ProductoLaboratorioController@store')->name('productos.guardar_laboratorio');
        Route::get('eliminar_laboratorio/{id}', 'ProductoLaboratorioController@destroy')->name('productos.eliminar_laboratorio');
        Route::get('editar_laboratorio/{object}', 'ProductoLaboratorioController@edit')->name('productos.editar_laboratorio');
        Route::put('actualizar_laboratorio/{object}', 'ProductoLaboratorioController@update')->name('productos.actualizar_laboratorio');
        //Grupo Terapeutico
        Route::get('listado_grupo_terapeutico', 'ProductoGrupoTerapeuticoController@index')->name('productos.grupo_terapeutico');
        Route::get('nuevo_grupo_terapeutico', 'ProductoGrupoTerapeuticoController@create')->name('productos.nuevo_grupo_terapeutico');
        Route::post('guardar_grupo_terapeutico', 'ProductoGrupoTerapeuticoController@store')->name('productos.guardar_grupo_terapeutico');
        Route::get('eliminar_grupo_terapeutico/{id}', 'ProductoGrupoTerapeuticoController@destroy')->name('productos.eliminar_grupo_terapeutico');
        Route::get('editar_grupo_terapeutico/{object}', 'ProductoGrupoTerapeuticoController@edit')->name('productos.editar_grupo_terapeutico');
        Route::put('actualizar_grupo_terapeutico/{object}', 'ProductoGrupoTerapeuticoController@update')->name('productos.actualizar_grupo_terapeutico');
        //Lineas
        Route::get('listado_lineas', 'ProductoLineaController@index')->name('productos.lineas');
        Route::get('nuevo_linea', 'ProductoLineaController@create')->name('productos.nuevo_linea');
        Route::post('guardar_linea', 'ProductoLineaController@store')->name('productos.guardar_linea');
        Route::get('eliminar_linea/{id}', 'ProductoLineaController@destroy')->name('productos.eliminar_linea');
        Route::get('editar_linea/{linea}', 'ProductoLineaController@edit')->name('productos.editar_linea');
        Route::put('actualizar_linea/{linea}', 'ProductoLineaController@update')->name('productos.actualizar_linea');
        //Listado marcas
        Route::get('listado_marcas', 'ProductoMarcaController@index')->name('productos.marcas');
        Route::get('nuevo_marca', 'ProductoMarcaController@create')->name('productos.nuevo_marca');
        Route::post('guardar_marca', 'ProductoMarcaController@store')->name('productos.guardar_marca');
        Route::get('eliminar_marca/{id}', 'ProductoMarcaController@destroy')->name('productos.eliminar_marca');
        Route::get('editar_marca/{object}', 'ProductoMarcaController@edit')->name('productos.editar_marca');
        Route::put('actualizar_marca/{object}', 'ProductoMarcaController@update')->name('productos.actualizar_marca');
    });
    Route::group(['prefix' => 'pais'], function() {
        Route::get('lista', 'PaisesController@index')->name('pais.index');
        Route::get('nuevo', 'PaisesController@create')->name('pais.crear');
        Route::post('guardar', 'PaisesController@store')->name('pais.guardar');
        Route::get('editar/{pais}', 'PaisesController@edit')->name('pais.editar');
        Route::post('actualizar/{pais}', 'PaisesController@update')->name('pais.actualizar');
        Route::get('eliminar/{pais}', 'PaisesController@destroy')->name('pais.eliminar');
    });
    Route::group(['prefix' => 'departamento'], function() {
        Route::get('lista', 'DepartamentosController@index')->name('departamento.index');
        Route::get('nuevo', 'DepartamentosController@create')->name('departamento.crear');
        Route::post('guardar', 'DepartamentosController@store')->name('departamento.guardar');
        Route::get('editar/{departamento}', 'DepartamentosController@edit')->name('departamento.editar');
        Route::post('actualizar/{departamento}', 'DepartamentosController@update')->name('departamento.actualizar');
        Route::get('eliminar/{departamento}', 'DepartamentosController@destroy')->name('departamento.eliminar');
    });
    Route::group(['prefix' => 'municipio'], function() {
        Route::get('lista', 'MunicipiosController@index')->name('municipio.index');
        Route::get('nuevo', 'MunicipiosController@create')->name('municipio.crear');
        Route::post('guardar', 'MunicipiosController@store')->name('municipio.guardar');

        Route::get('editar/{municipio}', 'MunicipiosController@edit')->name('municipio.editar');
        Route::post('actualizar/{municipio}', 'MunicipiosController@update')->name('municipio.actualizar');
        Route::get('eliminar/{id}', 'MunicipiosController@destroy')->name('municipio.eliminar');
    });
    Route::group(['prefix' => 'zona'], function() {
        Route::get('lista', 'ZonasController@index')->name('zona.index');
        Route::get('nueva', 'ZonasController@create')->name('zona.crear');
        Route::post('guardar', 'ZonasController@store')->name('zona.guardar');

        Route::get('editar/{zona}', 'ZonasController@edit')->name('zona.editar');
        Route::post('actualizar/{zona}', 'ZonasController@update')->name('zona.actualizar');
        Route::get('eliminar/{id}', 'ZonasController@destroy')->name('zona.eliminar');
    });
    Route::group(['prefix' => 'codigo_postal'], function() {
        Route::get('lista', 'CodigoPostalController@index')->name('codigo.index');
        Route::get('nueva', 'CodigoPostalController@create')->name('codigo.crear');
        Route::post('guardar', 'CodigoPostalController@store')->name('codigo.guardar');

        Route::get('editar/{codigo}', 'CodigoPostalController@edit')->name('codigo.editar');
        Route::post('actualizar/{codigo}', 'CodigoPostalController@update')->name('codigo.actualizar');
        Route::get('eliminar/{id}', 'CodigoPostalController@destroy')->name('codigo.eliminar');
    });
    Route::group(['prefix' => 'region'], function() {
        Route::get('lista', 'RegionController@index')->name('region.index');
        Route::get('nueva', 'RegionController@create')->name('region.crear');
        Route::post('guardar', 'RegionController@store')->name('region.guardar');

        Route::get('editar/{region}', 'RegionController@edit')->name('region.editar');
        Route::post('actualizar/{region}', 'RegionController@update')->name('region.actualizar');
        Route::get('eliminar/{id}', 'RegionController@destroy')->name('region.eliminar');
    });
    Route::group(['prefix' => 'gira'], function() {
        Route::get('lista', 'GiraController@index')->name('gira.index');
        Route::get('nueva', 'GiraController@create')->name('gira.crear');
        Route::post('guardar', 'GiraController@store')->name('gira.guardar');

        Route::get('editar/{gira}', 'GiraController@edit')->name('gira.editar');
        Route::post('actualizar/{gira}', 'GiraController@update')->name('gira.actualizar');
        Route::get('eliminar/{id}', 'GiraController@destroy')->name('gira.eliminar');
    });

    Route::group(['prefix' => 'apm'], function() {
        Route::get('lista', 'ApmController@index')->name('apm.index');
        Route::get('nuevo', 'ApmController@create')->name('apm.crear');
        Route::post('guardar', 'ApmController@store')->name('apm.guardar');
        Route::get('editar/{apm}', 'ApmController@edit')->name('apm.editar');
        Route::post('actualizar/{apm}', 'ApmController@update')->name('apm.actualizar');
        Route::get('eliminar/{apm}', 'ApmController@destroy')->name('apm.eliminar');
    });
    Route::group(['prefix' => 'linea'], function() {
        Route::get('lista', 'LineaController@index')->name('linea.index');
        Route::get('nueva', 'LineaController@create')->name('linea.crear');
        Route::post('guardar', 'LineaController@store')->name('linea.guardar');
        Route::get('editar/{linea}', 'LineaController@edit')->name('linea.editar');
        Route::get('eliminar/{id}', 'LineaController@destroy')->name('linea.eliminar');
        Route::post('actualizar/{linea}', 'LineaController@update')->name('linea.actualizar');
    });
    Route::group(['prefix' => 'categoria'], function() {
        Route::get('lista', 'CategoriaController@index')->name('categoria.index');
        Route::get('nueva', 'CategoriaController@create')->name('categoria.crear');
        Route::post('guardar', 'CategoriaController@store')->name('categoria.guardar');
    });
    Route::group(['prefix' => 'clasificacion'], function() {
        Route::get('lista', 'ClasificacionController@index')->name('clasificacion.index');
        Route::get('nueva', 'ClasificacionController@create')->name('clasificacion.crear');
        Route::post('guardar', 'ClasificacionController@store')->name('clasificacion.guardar');
        Route::get('editar/{clasificacion}', 'ClasificacionController@edit')->name('clasificacion.editar');
        Route::post('actualizar/{clasificacion}', 'ClasificacionController@update')->name('clasificacion.actualizar');
        Route::get('eliminar/{clasificacion}', 'ClasificacionController@destroy')->name('clasificacion.eliminar');
    });
});



Auth::routes();

Route::get('/home', 'HomeController@index')->name('home');
